<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="26"/>
        <location filename="../src/about.cpp" line="37"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="82"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="133"/>
        <source>tab0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="178"/>
        <source>label_4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="191"/>
        <source>label_5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="204"/>
        <source>label_6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="230"/>
        <source>tab1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="257"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="316"/>
        <source>pushButton_3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="335"/>
        <source>pushButton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="38"/>
        <source>Currently used plugin</source>
        <translation>Verwendetes Plugin</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="44"/>
        <source>License: GPL-3.0+</source>
        <translation>Lizenz: GPL-3.0+</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <source>Version: </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>Patrice Coni</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Copyright © 2022 - </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <source>A wallpaper changer</source>
        <translation>Eine Anwendung zum Wechsel des Hintergrundbildes</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="64"/>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="65"/>
        <source>Visit website</source>
        <translation>Webseite besuchen</translation>
    </message>
    <message>
        <source>A simple application for changing wallpaper</source>
        <translation type="vanished">Eine einfache Anwendung zum Wechsel des Hintergrundbildes</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="93"/>
        <source>No connection to the internet.
The application will be closed.</source>
        <translation>Keine Verbindung zum Internet.
Die Anwendung wird geschlossen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Reset</source>
        <translation>Standardeinstellungen</translation>
    </message>
    <message>
        <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation type="vanished">Das Plugin-Verzeichnis wurde nicht gefunden. Möchten Sie das Verzeichnis, in dem sich die Plugins befinden, manuell festlegen?</translation>
    </message>
    <message>
        <source>Select directory</source>
        <translation type="vanished">Ordner auswählen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation>Der Speicherort der Plugins wurde nicht gefunden. Möchten Sie den Pfad manuell festlegen?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="125"/>
        <source>Select Plugin Folder</source>
        <translation>Ordner auswählen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="134"/>
        <source>No Plugins Found</source>
        <translation>Keine Plugins gefunden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="135"/>
        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
        <translation>Es wurden keine Plugins gefunden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>No plugins found.</source>
        <translation>Keine Plugins gefunden.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="329"/>
        <location filename="../src/mainwindow.cpp" line="806"/>
        <source>done.</source>
        <translation>erledigt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="807"/>
        <source>Used plugin: </source>
        <translation>Verwendetes Plugin: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error while loading plugin.</source>
        <translation>Fehler beim Laden des Plugins.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>An error was detected when starting the application.
The application will be closed.</source>
        <translation>Beim Start der Anwendung wurde ein Fehler festgestelt.
Die Anwendung wird nun beendet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>No connection to the internet.</source>
        <translation>Keine Internetverbindung.
Die Anwendung wird geschlossen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>Please check your internet connection.</source>
        <translation>Bitte überprüfen Sie Ihre Internetverbindung.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="796"/>
        <source>&amp;Provider</source>
        <translation>&amp;Anbieter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>&amp;About this picture and license</source>
        <translation>&amp;Über dieses Bild und Lizenz</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>&amp;About this picture and copyright</source>
        <translation>&amp;Über dieses Bild und Copyright</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="845"/>
        <source>&amp;Download past pictures</source>
        <translation>&amp;Ältere Bilder herunterladen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>&amp;Load stored picture</source>
        <translation>&amp;Gespeichertes Hintergrundbild laden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="852"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="858"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="873"/>
        <source>No internet connection.</source>
        <translation>Keine Internetverbindung.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="932"/>
        <source>Description: 
</source>
        <translation>Beschreibung: 
</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1256"/>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1257"/>
        <source>No internet connection available.</source>
        <translation>Keine Internetverbindung.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1518"/>
        <source>Load plugin...</source>
        <translation>Plugin wird geladen...</translation>
    </message>
</context>
<context>
    <name>PhotoBrowser</name>
    <message>
        <location filename="../src/photobrowser.ui" line="20"/>
        <location filename="../src/photobrowser.ui" line="58"/>
        <source>Load stored picture</source>
        <translation>Gespeichertes Hintergrundbild laden</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="90"/>
        <location filename="../src/photobrowser.ui" line="187"/>
        <source>&amp;Set as wallpaper</source>
        <translation>&amp;Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="174"/>
        <source>Select a photo</source>
        <translation>Bild auswählen</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="282"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Select date: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Datum auswählen: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="325"/>
        <source>&amp;Set current date</source>
        <translation>&amp;Aktuelles Datum auswählen</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="382"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Show photos of past days: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ältere Bilder anzeigen: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="449"/>
        <source>&amp;Show pictures</source>
        <translation>&amp;Zeige Bilder</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error while loading plugin.</source>
        <translation>Fehler beim Laden des Plugins.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="214"/>
        <source>Past pictures of the day (Wikimedia Commons)</source>
        <translation>Ältere Tagesbilder laden (Wikimedia Commons)</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="263"/>
        <source>Get more information</source>
        <translation>Mehr informationen</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="430"/>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="434"/>
        <source>Please select a picture.</source>
        <translation>Bitte wählen Sie ein Bild aus.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="442"/>
        <source>Title: </source>
        <translation>Titel: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="448"/>
        <source>Description: </source>
        <translation>Beschreibung: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="460"/>
        <source>Picture size:</source>
        <translation>Bildgrösse:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="470"/>
        <source>Preview:</source>
        <translation>Vorschau:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="508"/>
        <source>Download in progress...</source>
        <translation>Wird heruntergeladen...</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="551"/>
        <source>The entered date must not be in the future.</source>
        <translation>Das Datum darf nicht in der Zukunft liegen.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="641"/>
        <source>Working in progress...</source>
        <translation>In Bearbeitung...</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Download in progress...</source>
        <translation type="vanished">Wird heruntergeladen...</translation>
    </message>
    <message>
        <source>Working in progress...</source>
        <translation type="vanished">In Bearbeitung...</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../src/settingswindow.ui" line="23"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="37"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Location to save background photos: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Speicherort für die Hintergrundbilder: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="55"/>
        <source>Choose</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="72"/>
        <source>Delete wallpapers older than (days): </source>
        <translation>Hintergrundbilder löschen nach (Tage): </translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="121"/>
        <source>Change desktop background photo automatically</source>
        <translation>Hintergrundbild automatisch wechseln</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Time of day for changing wallpaper automatically: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Uhrzeit zum automatischen Wechsel des Hintergrundbildes: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="181"/>
        <source>Run Application at startup</source>
        <translation>Anwendung beim Systemstart automatisch starten</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="198"/>
        <source>Change lock screen wallpaper if possible</source>
        <translation>Hintergrundbild des Sperrbildschirm wechseln wenn möglich</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="240"/>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>Reset</source>
        <translation>Standardeinstellungen</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="272"/>
        <source>Save settings</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="291"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>Save changes</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>The application will be restart for the changes to take effect. Do you want save the changes?</source>
        <translation>Die Anwendung muss neu gestartet werden, damit die Änderungen aktiv werden. Möchten Sie die Einstellungen speichern?</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="155"/>
        <source>Select directory</source>
        <translation>Ordner auswählen</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
        <translation>Es werden alle Einstellungen zurückgesetzt. Alle gespeicherten Hintergrundbilder werden gelöscht. Möchten Sie fortfahren?</translation>
    </message>
</context>
<context>
    <name>setWallpaper</name>
    <message>
        <location filename="../src/setwallpaper.cpp" line="207"/>
        <source>Error: Failed to set wallpaper on macOS.</source>
        <translation>Fehler - Hintergrundbild konnte nicht geladen werden.</translation>
    </message>
    <message>
        <location filename="../src/setwallpaper.cpp" line="218"/>
        <source>Error - Failed to set wallpaper.</source>
        <translation>Fehler - Hintergrundbild konnte nicht geladen werden.</translation>
    </message>
</context>
</TS>
